pub struct LinTree<'a, T> { /* private fields */ }Expand description
A tree whose nodes are stored in a backing slice.
The root node is at index 0 and the child
nodes at index*2 + 1 and index*2 + 2.
Used in most examples, as it is easy to initialize.
Also shows a case where Treelike is implemented on the node itself, and not a reference to one.
An important pitfall for that is that you may need to manually implement Copy and Clone as
deriving them places Copy/Clone bounds on all type parameters (T in this case), even
though that might not be necessary due to the content not being stored in-line, and therefore
not being Copy/Cloned.
Implementations